@@ -1,5 +1,4 @@
 import objectpath
-import logging
 import numpy as np
 import yahoo_fantasy_api as yfa
 from deez_stats.pyquery import database_query as dbq
@@ -7,9 +6,6 @@ from deez_stats.pyquery import yahoo_query as yq
 from deez_stats.pyquery import json_query as jq
 
 
-logging.basicConfig(level=logging.INFO)
-
-
 class LeagueInfo:
     def __init__(self, sc, season=None, week=None):
         self.sc = sc
@@ -32,24 +28,28 @@ class LeagueInfo:
         self.manager_names = None
         self._update_LeagueInfo()
 
-    def get_weekly_matchups(self, with_names=True):
+    def get_weekly_matchups(self):
         matchups = yfa.League(self.sc, self.league_key).matchups(week=self.week)
         tree = objectpath.Tree(matchups)
         self.weekly_matchups = []
         self.weekly_matchups.append(list(map(int, list(tree.execute('$..team_id')))))
         self.weekly_matchups.append(list(map(float, list(tree.execute('$..team_points.total')))))
         self.weekly_matchups = np.array(self.weekly_matchups).T.tolist()  # transpose array to pair id with team points
-        if with_names is True:
-            for i in self.weekly_matchups:
-                i[0] = self.manager_names[i[0]]
-        logging.info('Found weekly matchups')
+        for i in self.weekly_matchups:
+            i[0] = self.manager_names[i[0]]
+        for matchup in self.weekly_matchups:
+            elo = dbq.get_manager_elo(self.season, self.week, matchup[0])
+            matchup.append(elo)
 
     def get_weekly_matchup_history(self):
         wmh = []
         for i in range(self.num_matchups):
-            wmh.append(dbq.matchup_history(self.weekly_matchups[2 * i][0], self.weekly_matchups[2 * i + 1][0]))
+            manager_name = self.weekly_matchups[2 * i][0]
+            opponent_name = self.weekly_matchups[2 * i + 1][0]
+            manager_elo = self.weekly_matchups[2 * i][2]
+            opponent_elo = self.weekly_matchups[2 * i + 1][2]
+            wmh.append(dbq.matchup_history(manager_name, manager_elo, opponent_name, opponent_elo))
             # matchups will be returned in the order manager[2*i] will always compete against manager[2*i+1]
-        logging.info('Returning weekly matchup history object')
         return wmh
 
     def season_to_league_key(self):
@@ -84,7 +84,6 @@ class LeagueInfo:
         self.get_current_season()
         if self.season is None:  # grab current season
             self.season = self.cur_season
-            logging.info('No season specified, using current season.')
         self.league_key = self.season_to_league_key()
         league = yfa.League(self.sc, self.league_key)
         settings = league.settings()
@@ -101,6 +100,5 @@ class LeagueInfo:
         self.game_code = jq.search_json_key(settings, '.game_code')
         if self.week is None:
             self.week = jq.search_json_key(settings, '.current_week')
-            logging.info('No week specified, using current week.')
         self.get_manager_names(league)
         self.get_weekly_matchups()
